@@ -41,6 +41,20 @@ class BaseModel(models.Model):
     class Meta:
         abstract = True
 
+    UNIQUE_FIELDS = []
+
+    def clean_unique(self):
+        if not self.UNIQUE_FIELDS:
+            return True
+        filters = {f: getattr(self, f) for f in self.UNIQUE_FIELDS}
+        if self.__class__.objects.filter(is_deleted=False, **filters).filter(~models.Q(pk=self.pk)).exists():
+            data = ', '.join([f'{field_name} {getattr(self, field_name)}' for field_name in self.UNIQUE_FIELDS])
+            raise Error(message=f'{data} already exist!', field_name=self.UNIQUE_FIELDS[-1])
+
+    def clean(self):
+        self.clean_unique()
+        super(BaseModel, self).clean()
+
     def handle_create(self):
         pass
 
@@ -67,11 +81,14 @@ class BaseTrackedModel(BaseModel):
     creator = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.SET_NULL,
                                 null=True, blank=True, related_name='%(class)s_creator_user')
 
-    def __init__(self, *args, **kwargs):
-        super(BaseTrackedModel, self).__init__(*args, **kwargs)
+    def clean_creator(self):
         if self.editor and not self.creator:  # TODO move this to save
             self.creator = self.editor
 
+    def clean(self):
+        self.clean_creator()
+        super(BaseTrackedModel, self).clean()
+
     @classmethod
     def get_user_field(cls):
         raise NotImplemented('Refer user_field for filtering')
