@@ -9,23 +9,34 @@ from crud_framework.errors import Error
 from django.conf import settings
 from django.core.exceptions import ValidationError
 
+from django.db.models import Q
+
 
 def my_furl(url):  # TODO test injection
     args = furl(url=url).args
     filters = {}
     q_filters = []
-    print(args)
     for k in args.keys():
         vs = args.allvalues(k)
         if len(vs) > 1:  # List filter
             filters[k] = vs
         else:
             vs = vs[0]  # Normal filter
-            if '|' in vs:  # OR filter
-                q_filters.append(
-                    '|'.join(['Q({}={})'.format(k, vs.split('|')[0])] + [f'Q({i})' for i in vs.split('|')[1:]]))
-    print('filters: ', filters)
-    print('QS: ', q_filters)
+            if '|' not in vs:  # Doesnt contain OR
+                filters[k] = vs
+            else:  # OR filter
+                f = {k: vs.split('|')[0]}  # First argument
+                d = []
+                ff = Q(**f)
+                for i in vs.split('|')[1:]:  # Rest of OR arguments
+                    j = i.split('=')
+                    f = {j[0]: j[1]}
+                    d.append(Q(**f))
+
+                for f in d:
+                    ff = ff | f
+                q_filters.append((ff))
+
     return filters, q_filters
 
 
@@ -34,10 +45,7 @@ def view_catch_error(f):
         if hasattr(settings, 'logger'):
             settings.logger.info(f'REQUEST: {request.method} || URL: {request.build_absolute_uri()}')
         try:
-            try:
-                filters, q_filters = my_furl(request.build_absolute_uri())
-            except:
-                filters, q_filters = {}, []
+            filters, q_filters = my_furl(request.build_absolute_uri())
 
             return f(request=request, filters=filters, q_filters=q_filters, *args, **kwargs)
 
